@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: adjunctions
 version: 4.3
-id: adjunctions-4.3-efc57e5fce33f38939dda45ec9d74b3b
-key: adjun_9BZLUWJrhVD8XOEwWTBxG8
+id: adjunctions-4.3-4ea5517ab8878ad5d6d1874f8242d7cd
+key: adjun_BfkyfjtqRdK2S8HPcjqDko
 license: BSD3
 copyright: Copyright (C) 2011-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,18 +26,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
-hs-libraries: HSadjunctions-4.3-9BZLUWJrhVD8XOEwWTBxG8
+hs-libraries: HSadjunctions-4.3-BfkyfjtqRdK2S8HPcjqDko
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-caa084d849f0fd836e529854caff7fc2
+    comonad-5-9a3bede31f7f9dbe4efd0f02bc9ca766
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     contravariant-1.4-40742dd1a022cbf40c8c77a36d4f0610
-    distributive-0.5.0.2-161dd77efe370865be21560ce248cc64
-    free-4.12.4-933d8993d0b07bad69ead57266997de9
+    distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
+    free-4.12.4-00d655da7510c123b23f3d4ff9d2e676
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    profunctors-5.2-69458fa119e6a2dfd209808104f4439d
-    semigroupoids-5.0.1-71b3eb635555631c006bdf0054367a98
+    profunctors-5.2-9bddc68ddf0f4fcea803005a53816983
+    semigroupoids-5.0.1-e4734876ceb621b0eefb491ac209dad3
     semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
